package api.test.core;

import cucumber.api.java.en.And;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.openqa.selenium.Dimension;
import selenium.utils.*;


public class SeleniumStepDefinitions extends BaseStepDefinitions {
    private static final Logger logger = LogManager.getLogger(SeleniumStepDefinitions.class.getSimpleName());

    @And("^I close the browser$")
    public void iCloseTheBrowser() throws Throwable {
        Browser.driver.manage().deleteAllCookies();
        Browser.tearDown();
        logger.debug("BROWSER CLOSED");
    }

    /**
     *
     * @param browser - acceptable values are Chrome, HTMLUnitDriver
     * @throws Throwable
     */
    @And("^I start the browser \\{(.*?)\\}$")
    public void iStartTheBrowser(String browser) throws Throwable {
        switch(browser.toLowerCase()) {
            case "chrome":
                Browser.initChrome();
                break;
            default:
                throw new IllegalArgumentException("Invalid browser: " + browser);
        }
        logger.debug("BROWSER STARTED: {}" , browser);
    }

    @And("^I resize the browser to width \\{(.*?)\\} and height \\{(.*?)\\}$")
    public void iResizeTheBrowser(int width, int height) throws Throwable {
        Dimension dim = new Dimension(width,height);
        Browser.driver.manage().window().setSize(dim);
    }

    @And("^I refresh the current page$")
    public void iRefreshTheCurrentPage(){
        Browser.driver.navigate().refresh();
    }

    @And("^I validate the page title is \\{(.*?)\\}$")
    public void i_validate_the_page_title_is(String title) throws Throwable {
        Browser.validatePageTitle(title);
    }
}
